Additional information — CGDAT 2.0.3-3-g9aff488 documentation

# Additional information

## Licence

This tool is licensed under the GPL open source license. You are therefore free use the source code in any way provided that you the original copyright statements.

## Release History

- 2.0.4:

  > - FIX: Fixes README.rst pypi incompatibility problem.

- 2.0.3:

  > - CHANGE: Updated the images in the READme.rst to raw github images.

- 2.0.2:

  > - CHANGE: Updated the setup.py and the project Readme.md.

- 2.0.1:

  > - CHANGE(docs): Updated docs (module code remains unchanged).

- 2.0.0:

  > - First proper release on PiPy.

## Meta

Rick Staa – @github

Distributed under the GNU General Public License v3 (GPLv3). See LICENSE for more information.

## Contributing

1. Fork it (<https://github.com/rickstaa/CGDAT>)
2. Create your feature branch (git checkout -b feature/fooBar)
3. Commit your changes (git commit -am ‘Add some fooBar’)
4. Push to the branch (git push origin feature/fooBar)
5. Create a new Pull Request

## Contributors

- Created by Rick Staa
- Maintained by Wesley Bosman (wesleybosmann@gmail.com)

## Credits

- CDAT icon created by FreePis from www.flaticon.com.